pyclearsky
==========


.. image:: https://img.shields.io/pypi/v/pyclearsky.svg
        :target: https://pypi.python.org/pypi/pyclearsky

.. image:: https://img.shields.io/travis/santoshphilip/pyclearsky.svg
        :target: https://travis-ci.org/santoshphilip/pyclearsky

.. image:: https://readthedocs.org/projects/pyclearsky/badge/?version=latest
        :target: https://pyclearsky.readthedocs.io/en/latest/?badge=latest
        :alt: Documentation Status




implements the equations from Ashrae Fundamentals 2009 for clear sky in Python


* Free software: Mozilla Public License Version 2.0
* Documentation: https://pyclearsky.readthedocs.io.


Features
--------

* TODO
    * implement in python3

Credits
-------

This package was created with Cookiecutter_ and the `audreyr/cookiecutter-pypackage`_ project template.

.. _Cookiecutter: https://github.com/audreyr/cookiecutter
.. _`audreyr/cookiecutter-pypackage`: https://github.com/audreyr/cookiecutter-pypackage
